@@ -26,56 +26,10 @@ from .common import *
 from .contexts import ExprValueCtx, ScopeCtx, ValueTypeCtx
 from .expression import Expression
 from .gobject_object import Object
+from .translated import *
 from .types import TypeName
 
 
-class Translated(AstNode):
-    grammar = AnyOf(
-        ["_", "(", UseQuoted("string"), ")"],
-        [
-            "C_",
-            "(",
-            UseQuoted("context"),
-            ",",
-            UseQuoted("string"),
-            ")",
-        ],
-    )
-
-    @property
-    def string(self) -> str:
-        return self.tokens["string"]
-
-    @property
-    def translate_context(self) -> T.Optional[str]:
-        return self.tokens["context"]
-
-    @validate()
-    def validate_for_type(self) -> None:
-        expected_type = self.context[ValueTypeCtx].value_type
-        if expected_type is not None and not expected_type.assignable_to(StringType()):
-            raise CompileError(
-                f"Cannot convert translated string to {expected_type.full_name}"
-            )
-
-    @validate("context")
-    def context_double_quoted(self):
-        if self.translate_context is None:
-            return
-
-        if not str(self.group.tokens["context"]).startswith('"'):
-            raise CompileWarning("gettext may not recognize single-quoted strings")
-
-    @validate("string")
-    def string_double_quoted(self):
-        if not str(self.group.tokens["string"]).startswith('"'):
-            raise CompileWarning("gettext may not recognize single-quoted strings")
-
-    @docs()
-    def ref_docs(self):
-        return get_docs_section("Syntax Translated")
-
-
 class TypeLiteral(AstNode):
     grammar = [
         "typeof",
@@ -132,6 +86,10 @@ class QuotedLiteral(AstNode):
     def value(self) -> str:
         return self.tokens["value"]
 
+    @property
+    def value_token(self) -> Token:
+        return self.group.tokens["value"]
+
     @property
     def type(self):
         return gir.StringType()
@@ -165,6 +123,9 @@ class QuotedLiteral(AstNode):
                 "Gdk.ContentFormats",
                 "Gsk.Transform",
                 "GLib.Variant",
+                "Pango.AttrList",
+                "Pango.FontDescription",
+                "Pango.TabArray",
             ]
             if expected_type.full_name not in parseable_types:
                 hints = []
@@ -338,7 +299,14 @@ class IdentLiteral(AstNode):
                         raise CompileError(
                             '"item" can only be used in an expression literal'
                         )
-                elif self.ident not in ["true", "false"]:
+                elif self.ident in ["true", "false"]:
+                    if expected_type is not None and not isinstance(
+                        expected_type, gir.BoolType
+                    ):
+                        raise CompileError(
+                            f"Cannot assign boolean to {expected_type.full_name}"
+                        )
+                else:
                     raise CompileError(
                         f"Could not find object with ID {self.ident}",
                         did_you_mean=(
